@@ -2,23 +2,28 @@ from tofa.__version__ import __version__
 from tofa.config import BoolFlagAction, Config, ConfigArgumentParser
 from tofa.filesystem import as_path, existing_path, make_path
 from tofa.io import load, save
+from tofa.logging import basic_config, make_logger
 from tofa.misc import AttribDict
 from tofa.registry import Registry
 from tofa.torch_utils import as_numpy, as_scalar, as_tensor
+from tofa.visualization import imshow_debug
 
 __all__ = [
     "__version__",
-    "Registry",
-    "Config",
-    "BoolFlagAction",
-    "ConfigArgumentParser",
-    "AttribDict",
     "as_numpy",
+    "as_path",
     "as_scalar",
     "as_tensor",
-    "load",
-    "save",
-    "make_path",
+    "AttribDict",
+    "basic_config",
+    "BoolFlagAction",
+    "Config",
+    "ConfigArgumentParser",
     "existing_path",
-    "as_path",
+    "imshow_debug",
+    "load",
+    "make_logger",
+    "make_path",
+    "Registry",
+    "save",
 ]
